@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.EC2 1.24.36\nVersion:         1.24.36.post1\nBuilder version:"
-        " 7.10.0\nDocs:           "
+        "Type annotations for boto3.EC2 1.24.41\nVersion:         1.24.41\nBuilder version:"
+        " 7.10.2\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_ec2//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/ec2.html#EC2\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.24.36.post1")
+    print("1.24.41")
 
 
 def main() -> None:
