@@ -1626,6 +1626,7 @@ ResetFpgaImageAttributeNameType = Literal["loadPermission"]
 ResetImageAttributeNameType = Literal["launchPermission"]
 ResourceTypeType = Literal[
     "capacity-reservation",
+    "capacity-reservation-fleet",
     "carrier-gateway",
     "client-vpn-endpoint",
     "customer-gateway",
@@ -1678,6 +1679,7 @@ ResourceTypeType = Literal[
     "subnet",
     "subnet-cidr-reservation",
     "traffic-mirror-filter",
+    "traffic-mirror-filter-rule",
     "traffic-mirror-session",
     "traffic-mirror-target",
     "transit-gateway",
@@ -1690,6 +1692,7 @@ ResourceTypeType = Literal[
     "volume",
     "vpc",
     "vpc-endpoint",
+    "vpc-endpoint-connection-device-type",
     "vpc-endpoint-service",
     "vpc-flow-log",
     "vpc-peering-connection",
